vfbLib.parsers.truetype.TrueTypeZoneDeltasParser
================================================

.. currentmodule:: vfbLib.parsers.truetype

.. autoclass:: TrueTypeZoneDeltasParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TrueTypeZoneDeltasParser.__init__
      ~TrueTypeZoneDeltasParser.parse
      ~TrueTypeZoneDeltasParser.parse_hex
      ~TrueTypeZoneDeltasParser.read_double
      ~TrueTypeZoneDeltasParser.read_doubles
      ~TrueTypeZoneDeltasParser.read_float
      ~TrueTypeZoneDeltasParser.read_floats
      ~TrueTypeZoneDeltasParser.read_int16
      ~TrueTypeZoneDeltasParser.read_int32
      ~TrueTypeZoneDeltasParser.read_int8
      ~TrueTypeZoneDeltasParser.read_str
      ~TrueTypeZoneDeltasParser.read_str_all
      ~TrueTypeZoneDeltasParser.read_uint16
      ~TrueTypeZoneDeltasParser.read_uint32
      ~TrueTypeZoneDeltasParser.read_uint8
      ~TrueTypeZoneDeltasParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TrueTypeZoneDeltasParser.encoding
      ~TrueTypeZoneDeltasParser.master_count
      ~TrueTypeZoneDeltasParser.stream
      ~TrueTypeZoneDeltasParser.ttStemsH_count
      ~TrueTypeZoneDeltasParser.ttStemsV_count
   
   